@@ -15,13 +15,7 @@ describe 'horizon' do
     File.expand_path(File.join(__FILE__, '..', '..', 'fixtures'))
   end
 
-  let :facts do
-    { :concat_basedir => '/var/lib/puppet/concat',
-      :fqdn           => 'some.host.tld'
-    }
-  end
-
-  shared_examples 'horizon' do
+  shared_examples_for 'horizon' do
 
     context 'with default parameters' do
       it {
@@ -31,14 +25,20 @@ describe 'horizon' do
           )
       }
       it { is_expected.to contain_exec('refresh_horizon_django_cache').with({
-          :command     => '/usr/share/openstack-dashboard/manage.py collectstatic --noinput --clear && /usr/share/openstack-dashboard/manage.py compress --force',
+          :command     => '/usr/share/openstack-dashboard/manage.py collectstatic --noinput --clear',
+          :refreshonly => true,
+      })}
+      it { is_expected.to contain_exec('refresh_horizon_django_compress').with({
+          :command     => '/usr/share/openstack-dashboard/manage.py compress --force',
           :refreshonly => true,
       })}
       it {
         if facts[:os_package_type] == 'rpm'
           is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
+          is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
         else
           is_expected.to_not contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
+          is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
         end
       }
 
@@ -59,8 +59,10 @@ describe 'horizon' do
           "LOGIN_REDIRECT_URL = '#{platforms_params[:root_url]}/'",
           "ALLOWED_HOSTS = ['*', ]",
           "  'identity': 3,",
+          'HORIZON_CONFIG["password_autocomplete"] = "off"',
+          'HORIZON_CONFIG["images_panel"] = "legacy"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
-          'OPENSTACK_KEYSTONE_URL = "http://127.0.0.1:5000/v2.0"',
+          'OPENSTACK_KEYSTONE_URL = "http://127.0.0.1:5000"',
           'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "_member_"',
           "    'can_set_mount_point': True,",
           "    'can_set_password': False,",
@@ -106,6 +108,7 @@ describe 'horizon' do
           :compress_offline             => false,
           :hypervisor_options           => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options               => {'enable_backup' => true },
+          :keystone_options             => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
           :neutron_options              => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
                                             'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
@@ -121,7 +124,9 @@ describe 'horizon' do
             { 'name' => 'default', 'label' => 'Default', 'path' => 'themes/default' },
             { 'name' => 'material', 'label' => 'Material', 'path' => 'themes/material' },
           ],
-          :default_theme                => 'default'
+          :default_theme                => 'default',
+          :password_autocomplete        => 'on',
+          :images_panel                 => 'angular',
         })
       end
 
@@ -134,6 +139,8 @@ describe 'horizon' do
           "  'identity': 2.0,",
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
+          'HORIZON_CONFIG["password_autocomplete"] = "on"',
+          'HORIZON_CONFIG["images_panel"] = "angular"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
           "                'DEAD_RETRY': 1,",
           "                'SERVER_RETRIES': 1,",
@@ -144,6 +151,14 @@ describe 'horizon' do
           'OPENSTACK_KEYSTONE_URL = "https://keystone.example.com:4682"',
           'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "SwiftOperator"',
           'OPENSTACK_SSL_NO_VERIFY = True',
+          "OPENSTACK_KEYSTONE_BACKEND = {",
+          "    'name': 'native',",
+          "    'can_edit_user': True,",
+          "    'can_edit_group': True,",
+          "    'can_edit_project': True,",
+          "    'can_edit_domain': False,",
+          "    'can_edit_role': False,",
+          "}",
           "    'can_set_mount_point': False,",
           "    'can_set_password': True,",
           "    'enable_backup': True,",
@@ -175,6 +190,7 @@ describe 'horizon' do
       end
 
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
+      it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
 
       it { is_expected.to contain_file(params[:file_upload_temp_dir]) }
     end
@@ -193,6 +209,7 @@ describe 'horizon' do
       end
 
       it { is_expected.to contain_exec('refresh_horizon_django_cache') }
+      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
     context 'installs python memcache library when cache_backend is set to memcache' do
@@ -204,8 +221,7 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
-          :ensure => 'present',
-          :tag    => ['openstack', 'horizon-package']
+          :tag    => ['openstack']
          )
       }
     end
@@ -263,8 +279,8 @@ describe 'horizon' do
       before do
         params.merge!({
           :available_regions => [
-            ['http://region-1.example.com:5000/v2.0', 'Region-1'],
-            ['http://region-2.example.com:5000/v2.0', 'Region-2']
+            ['http://region-1.example.com:5000', 'Region-1'],
+            ['http://region-2.example.com:5000', 'Region-2']
           ]
         })
       end
@@ -272,8 +288,8 @@ describe 'horizon' do
       it 'AVAILABLE_REGIONS is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           "AVAILABLE_REGIONS = [",
-          "    ('http://region-1.example.com:5000/v2.0', 'Region-1'),",
-          "    ('http://region-2.example.com:5000/v2.0', 'Region-2'),",
+          "    ('http://region-1.example.com:5000', 'Region-1'),",
+          "    ('http://region-2.example.com:5000', 'Region-2'),",
           "]"
         ])
       end
@@ -394,25 +410,41 @@ describe 'horizon' do
         ])
       end
     end
+
+    context 'with websso enabled' do
+      before do
+        params.merge!({
+                        :websso_enabled => 'True',
+                        :websso_initial_choice => 'acme',
+                        :websso_choices => [
+                          ['oidc', 'OpenID Connect'],
+                          ['saml2', 'Security Assertion Markup Language'],
+                        ],
+                        :websso_idp_mapping => {
+                          'acme_oidc'  => ['acme', 'oidc'],
+                          'acme_saml2' => ['acme', 'saml2'],
+                        }
+                      })
+      end
+      it 'configures websso options' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+                                          'WEBSSO_ENABLED = True',
+                                          'WEBSSO_INITIAL_CHOICE = "acme"',
+                                          'WEBSSO_CHOICES = (',
+                                          '    ("credentials", _("Keystone Credentials")),',
+                                          '    ("oidc", _("OpenID Connect")),',
+                                          '    ("saml2", _("Security Assertion Markup Language")),',
+                                          ')',
+                                          'WEBSSO_IDP_MAPPING = {',
+                                          '    "acme_oidc": ("acme", "oidc"),',
+                                          '    "acme_saml2": ("acme", "saml2"),',
+                                          '}',
+                                        ])
+      end
+    end
   end
 
-  context 'on RedHat platforms' do
-    before do
-      facts.merge!({
-        :osfamily               => 'RedHat',
-        :operatingsystemrelease => '6.0',
-        :os_package_type        => 'rpm'
-      })
-    end
-
-    let :platforms_params do
-      { :config_file       => '/etc/openstack-dashboard/local_settings',
-        :package_name      => 'openstack-dashboard',
-        :root_url          => '/dashboard' }
-    end
-
-    it_behaves_like 'horizon'
-
+  shared_examples_for 'horizon on RedHat' do
     it 'sets WEBROOT in local_settings.py' do
       verify_concat_fragment_contents(catalogue, 'local_settings.py', [
         "WEBROOT = '/dashboard/'",
@@ -420,24 +452,7 @@ describe 'horizon' do
     end
   end
 
-  context 'on Debian platforms' do
-    before do
-      facts.merge!({
-        :osfamily               => 'Debian',
-        :operatingsystemrelease => '6.0',
-        :operatingsystem        => 'Debian',
-        :os_package_type        => 'debian'
-      })
-    end
-
-    let :platforms_params do
-      { :config_file       => '/etc/openstack-dashboard/local_settings.py',
-        :package_name      => 'openstack-dashboard-apache',
-        :root_url          => '/horizon' }
-    end
-
-    it_behaves_like 'horizon'
-
+  shared_examples_for 'horizon on Debian' do
     it 'sets WEBROOT in local_settings.py' do
       verify_concat_fragment_contents(catalogue, 'local_settings.py', [
         "WEBROOT = '/horizon/'",
@@ -445,28 +460,34 @@ describe 'horizon' do
     end
   end
 
-  context 'on Ubuntu platforms' do
-    before do
-      facts.merge!({
-        :osfamily               => 'Debian',
-        :operatingsystem        => 'Ubuntu',
-        :operatingsystemrelease => '14.04',
-        :os_package_type        => 'ubuntu'
-      })
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({
+          :fqdn           => 'some.host.tld',
+          :processorcount => 2,
+          :concat_basedir => '/var/lib/puppet/concat'
+        }))
+      end
 
-    let :platforms_params do
-      { :config_file       => '/etc/openstack-dashboard/local_settings.py',
-        :package_name      => 'openstack-dashboard',
-        :root_url          => '/horizon' }
-    end
+      let(:platforms_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :config_file       => '/etc/openstack-dashboard/local_settings.py',
+            :package_name      => 'openstack-dashboard',
+            :root_url          => '/horizon' }
+        when 'RedHat'
+          { :config_file       => '/etc/openstack-dashboard/local_settings',
+            :package_name      => 'openstack-dashboard',
+            :root_url          => '/dashboard' }
+        end
+      end
 
-    it_behaves_like 'horizon'
-
-    it 'sets WEBROOT in local_settings.py' do
-      verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-        "WEBROOT = '/horizon/'",
-      ])
+      it_behaves_like 'horizon'
+      it_behaves_like "horizon on #{facts[:osfamily]}"
     end
   end
+
 end
